
%global optflags %{optflags} -DGLM_ENABLE_EXPERIMENTAL

Name:           asymptote
Version:        2.86
Release:    1%{?dist}
Summary:        Descriptive vector graphics language
License:        LGPL-3.0-or-later
URL:            http://asymptote.sourceforge.net/
Source0:        http://download.sourceforge.net/sourceforge/asymptote/asymptote-%{version}.src.tgz
Source1:        asy.gif
Source2:        xasy.desktop
Source3:        asymptote.sty.204
Patch0:         asymptote-2.84-settings.patch
Patch3:         asymptote-2.73-info-path-fix.patch
Patch4:		asymptote-2.81-libtirpc.patch
Patch5:		asymptote-2.52-const-memrchr.patch
Patch6:         asymptote-2.63-freeglut.patch

BuildRequires:  gcc-c++
BuildRequires:  bison, flex
BuildRequires:  ncurses-devel
BuildRequires:  readline-devel
BuildRequires:  fftw-devel >= 3.0
BuildRequires:  gc-devel >= 6.8
BuildRequires:  gsl-devel
BuildRequires:  tex(latex) tex(epsf.tex)
BuildRequires:  tex(cm-super-t1.enc)
BuildRequires:  tex(media9.sty)
BuildRequires:  tex(parskip.sty)
BuildRequires:  ghostscript >= 9.55
BuildRequires:  texinfo-tex
BuildRequires:  ImageMagick
BuildRequires:  desktop-file-utils
BuildRequires:  freeglut-devel
BuildRequires:  zlib-devel
BuildRequires:  libtool
BuildRequires:  libglvnd-devel
BuildRequires:  emacs
BuildRequires:  libtirpc-devel
BuildRequires:  glm-devel
BuildRequires:  boost-devel, rapidjson-devel
BuildRequires:  cmake, make, python3-qt5
Requires:       emacs-filesystem >= %{_emacs_version}
Provides:	emacs-%{name} = %{version}-%{release}
Provides:	emacs-%{name}-el = %{version}-%{release}
Provides:	xemacs-%{name} = %{version}-%{release}
Provides:	xemacs-%{name}-el = %{version}-%{release}

Requires:       tex(latex)
Requires:       texlive-dvisvgm
Requires:       python3-qt5
Requires:       python3-cson, python3-speg
Requires:       python3-imaging-tk
Requires:       python3-numpy
Recommends:     evince, xdg-utils

Requires(post): texlive-kpathsea-bin, tex-kpathsea
Requires(postun): texlive-kpathsea-bin, tex-kpathsea

%define texpkgdir   %{_texmf}/tex/latex/%{name}

%description
Asymptote is a powerful descriptive vector graphics language for technical
drawings, inspired by MetaPost but with an improved C++-like syntax.
Asymptote provides for figures the same high-quality level of typesetting
that LaTeX does for scientific text.

%prep
%setup -q
%patch -P0 -p1 -b .settings
%patch -P3 -p1 -b .path-fix
%patch -P4 -p1 -b .libtirpc
%patch -P5 -p1 -b .const-memrchr
%patch -P6 -p1 -b .glut
%{__sed} -i 's/\r//' doc/CAD1.asy

iconv -f iso-8859-1 -t utf-8 -o examples/interpolate1.asy{.utf8,}
mv examples/interpolate1.asy{.utf8,}
autoreconf -i

%build
%configure --enable-gc=system --with-docdir=%{?_pkgdocdir}%{!?_pkgdocdir:%{_docdir}/%{name}-%{version}/} --with-latex=%{_texmf}/tex/latex --with-context=%{_texmf}/tex/context/ --enable-lsp
make %{?_smp_mflags}
cd doc/
make all

%install
%make_install 

install -p -m 644 BUGS ChangeLog LICENSE README ReleaseNotes TODO \
    %{buildroot}%{?_pkgdocdir}%{!?_pkgdocdir:%{_docdir}/%{name}-%{version}}

mkdir -p %{buildroot}%{_emacs_sitestartdir}
mkdir -p %{buildroot}%{_emacs_sitelispdir}/%{name}
cp -a %{buildroot}%{_datadir}/%{name}/*.el %{buildroot}%{_emacs_sitelispdir}/%{name}
mv %{buildroot}%{_emacs_sitelispdir}/%{name}/asy-init.el %{buildroot}%{_emacs_sitestartdir}
for i in %{buildroot}%{_emacs_sitelispdir}/%{name}/*.el; do
   %{_emacs_bytecompile} $i
done

install -dm 755 %{buildroot}%{_datadir}/vim/vimfiles/syntax
pushd %{buildroot}%{_datadir}/vim/vimfiles/syntax
ln -s ../../../%{name}/asy.vim .
popd
install -dm 755 %{buildroot}%{_datadir}/vim/vimfiles/ftdetect
pushd %{buildroot}%{_datadir}/vim/vimfiles/ftdetect
ln -s ../../../%{name}/asy_filetype.vim .
popd

mv %{buildroot}%{_infodir}/asymptote/asymptote.info %{buildroot}%{_infodir}/asymptote.info

mkdir -p %{buildroot}%{_datadir}/pixmaps/
cp %{SOURCE1} %{buildroot}%{_datadir}/pixmaps/

mkdir -p %{buildroot}%{_datadir}/applications
desktop-file-install --dir %{buildroot}%{_datadir}/applications %{SOURCE2}

rm -rf %{buildroot}%{_bindir}/xasy
cd %{buildroot}%{_bindir}
ln -s ../share/%{name}/GUI/xasy.py xasy

%post
texhash >/dev/null 2>&1 || :

%postun
texhash >/dev/null 2>&1 || :

%files
%doc %{?_pkgdocdir}%{!?_pkgdocdir:%{_docdir}/%{name}-%{version}/}
%{_bindir}/*
%{_datadir}/%{name}/
%{texpkgdir}/
%{_texmf}/tex/context/
%{_mandir}/man1/*.1*
%{_infodir}/*.info*
%{_datadir}/vim/vimfiles/syntax/asy.vim
%{_datadir}/vim/vimfiles/ftdetect/asy_filetype.vim
%{_datadir}/pixmaps/asy.gif
%{_datadir}/applications/*.desktop
%{_emacs_sitestartdir}/*.el
%{_emacs_sitelispdir}/%{name}/

%changelog
* Thu Oct 10 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.86-1
- initial build
